<?php

App::uses('EvTemplatesAppModel', 'EvTemplates.Model');

class Template extends EvTemplatesAppModel {

	public $actsAs = array(
		'EvCustomFields.CustomFields' => array(
			'formInject' => true
		)
	);

	public $validate = array(
		'name' => array(
			'notEmpty' => array(
				'rule' => array('notEmpty'),
				'message' => 'You must select a name for the template.',
				//'allowEmpty' => false,
				//'required' => false,
				//'last' => false, // Stop validation after this rule
				//'on' => 'create', // Limit validation to 'create' or 'update' operations
			),
		),
		'template' => array(
			'notEmpty' => array(
				'rule' => array('notEmpty'),
				'message' => 'You must select a view for the template.',
				//'allowEmpty' => false,
				//'required' => false,
				//'last' => false, // Stop validation after this rule
				//'on' => 'create', // Limit validation to 'create' or 'update' operations
			),
		),
	);

	public $hasMany = array(
		'ImageBlock' => array(
			'className' => 'EvTemplates.ImageBlock',
			'cascade' => true,
			'dependent' => true
		),
		'DocumentBlock' => array(
			'className' => 'EvTemplates.DocumentBlock',
			'cascade' => true,
			'dependent' => true
		)
	);

	/**
	 * redefine the readForEdit to bring out the blocks
	 *
	 * @param int       tempalte id
	 * @param array     extra params for the find
	 */
	public function readForEdit($id, $params = array()) {
		$params['contain'][] = 'ImageBlock';
		$params['contain'][] = 'DocumentBlock';

		return parent::readForEdit(
			$id,
			$params
		);
	}

	/**
	 * get all the templates in list format for the items dropdown
	 *
	 * @return array    Array of tmeplates
	 */
	public function selectList() {
		return $this->find(
			'list',
			array(
				'conditions' => array(
					'Template.is_active' => 1
				),
				'callbacks' => false
			)
		);
	}

	/**
	 * beforeSave, if nothing entered for the custom field data label, prefill it
	 *
	 * Called before each save operation, after validation. Return a non-true result
	 * to halt the save.
	 *
	 * @param array $options Options passed from Model::save().
	 * @return bool True if the operation should continue, false if it should abort
	 * @link http://book.cakephp.org/2.0/en/models/callback-methods.html#beforesave
	 * @see Model::save()
	 */
	public function beforeSave($options = array()) {
		$return = parent::beforeSave($options);

		if (empty($this->data['Template']['cfDataLabel'])) {
			$this->data['Template']['cfDataLabel'] = 'Custom Data';
		}
		return $return;
	}
}
